@@ -26,6 +26,14 @@ def room_lock(room_id: str):
         yield
 
 
+def create_room(room: BaseRoom):
+    redis_client.json().set(get_room_key(room.id), Path.root_path(), json.loads(room.json()))
+
+
+def delete_room(room_id: str):
+    redis_client.json().delete(get_room_key(room_id), Path.root_path())
+
+
 def get_room(room_id: str, model: type[RoomType]) -> RoomType:
     room_dict = redis_client.json().get(get_room_key(room_id), Path.root_path())
     return model.parse_obj(room_dict)
