@@ -28,7 +28,7 @@ class BaseRoom(BaseModel):
 
     @validator("mode", always=True)
     def compute_mode(cls, value):
-        return cls.get_mode()
+        return cls.get_mode() or value
 
     @staticmethod
     def get_mode() -> RoomMode:
